@@ -105,10 +105,11 @@ class DataFrame:
         document = str.lower(document)
         stopwords = stopwords_list
         words = word_tokenize(document)
+        clean_words = []
         for w in words:
-            if w in stopwords:
-                words.remove(w)
-        return ' '.join(words)
+            if w not in stopwords:
+                clean_words.append(w)
+        return ' '.join(clean_words)
     
     def add_random_series_column(self, column_name='random',min=0, max=100, distrubution_type='random', mean=0, sd=1):
         if distrubution_type == 'random':
